import argparse
from template import TempOps
from vm import VmOps
from net import NetOps
from disk import DiskOps
from storagedomain import StorageDomainOps
from utils import Help

from os import environ
from sys import argv


def main():
    parser = argparse.ArgumentParser()
    subparsers = parser.add_subparsers(dest='subparser')

    if argv[1].startswith('temp'):
        # Every operations that are related to template must start with "temp"
        tempops = TempOps()
        parser_templist = subparsers.add_parser('temp-list')
        parser_templist.add_argument('-p', '--prefix', default=environ.get("TITAMU_PREFIX"), dest='prefix')
        parser_templist.set_defaults(func=tempops.temp_list)

    elif argv[1].startswith('net'):
        # Every operations that are related to networks must start with "net"
        netops = NetOps()
        parser_netlist = subparsers.add_parser('net-list')
        parser_netlist.set_defaults(func=netops.net_list)

        parser_netadd = subparsers.add_parser('net-add')
        parser_netadd.add_argument('-n', '--network', dest='net_id')
        parser_netadd.add_argument('vm_name')
        parser_netadd.set_defaults(func=netops.net_add)

        parser_netadd = subparsers.add_parser('net-rm')
        parser_netadd.add_argument('-p', '--port', dest='port_id')
        parser_netadd.add_argument('vm_name')
        parser_netadd.set_defaults(func=netops.net_rm)

    elif argv[1].startswith('disk'):
        diskops = DiskOps()
        parser_disklist = subparsers.add_parser('disk-list')
        parser_disklist.add_argument('-p', '--prefix', default=environ.get("TITAMU_PREFIX"), dest='prefix')
        parser_disklist.add_argument('vm_name')
        parser_disklist.set_defaults(func=diskops.disk_list)

    elif argv[1].startswith('sd'):
        sdops = StorageDomainOps()
        parser_disklist = subparsers.add_parser('sd-list')
        parser_disklist.set_defaults(func=sdops.sd_list)

    elif argv[1].startswith('-h') or argv[1].startswith('--help') or argv[1].startswith('help'):
        help = Help()
        parser_help = subparsers.add_parser('-blabla')
        parser_help.set_defaults(func=help.print_help())

    else:
        vmops = VmOps()
        parser = argparse.ArgumentParser()
        subparsers = parser.add_subparsers(dest='subparser')

        parser_start = subparsers.add_parser('start')
        parser_start.add_argument('vm_name', help='Alpha description')
        parser_start.set_defaults(func=vmops.vm_start)

        # test
        parser_test = subparsers.add_parser('test')
        parser_test.set_defaults(func=vmops.vm_list)
        # test

        parser_stop = subparsers.add_parser('stop')
        parser_stop.add_argument('vm_name')
        parser_stop.set_defaults(func=vmops.vm_stop)

        parser_show = subparsers.add_parser('show')
        parser_show.add_argument('vm_name')
        parser_show.set_defaults(func=vmops.vm_show)

        parser_stop = subparsers.add_parser('delete')
        parser_stop.add_argument('vm_name')
        parser_stop.set_defaults(func=vmops.vm_delete)

        parser_list = subparsers.add_parser('list')
        parser_list.add_argument('-p', '--prefix', default=environ.get("TITAMU_PREFIX"), dest='prefix')
        parser_list.set_defaults(func=vmops.vm_list)

        parser_boot = subparsers.add_parser('boot')
        parser_boot.add_argument('-t', '--template', default=environ.get("TITAMU_DEFAULT_TEMPLATE"), dest='temp')
        parser_boot.add_argument('-c', '--comment', dest='vm_comment')
        parser_boot.add_argument('-d', '--dc', default=environ.get("TITAMU_DEFAULT_CLUSTER"), dest='vm_cluster')
        parser_boot.add_argument('-r', '--raw', default='0', dest='vm_raw')
        parser_boot.add_argument('vm_name')
        parser_boot.set_defaults(func=vmops.vm_boot)

        parser_console = subparsers.add_parser('console')
        parser_console.add_argument('vm_name')
        parser_console.set_defaults(func=vmops.vm_console)

        parser_console = subparsers.add_parser('get-console')
        parser_console.add_argument('vm_name')
        parser_console.set_defaults(func=vmops.vm_get_console)

    args = parser.parse_args(argv[1:])
    args.func(args)


if __name__ == "__main__":
    main()



#!/usr/bin/env python
# coding=utf-8

from setuptools import find_packages, setup

setup(
    name='titamu',
    version=0.65,
    description=(
        'A command line tool to talk with RHV environment'
    ),
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    author='Chen Chen',
    author_email='cchenlp@qq.com',
    license='BSD License',
    packages=['titamu'],
    platforms=["all"],
    url='https://github.com/cchen666/titamu',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Operating System :: OS Independent',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Programming Language :: Python :: 2.7',
        'Topic :: Software Development :: Libraries'
    ],
    scripts=['titamu/bin/titamu'],
    install_requires=[
    'ovirt-engine-sdk-python >= 4.2.9',
    'prettytable >= 0.7.2',
    ],
)



import ovirtsdk4 as sdk
import ovirtsdk4.types as types

from utils import Connect
from utils import Output


class NetOps:
    def __init__(self):
        self.connect = Connect()
        self.c = self.connect.connect()

    def net_list(self, args):
        networks_service = self.c.system_service().networks_service()
        try:
            networks = networks_service.list()
            rows = []
            for network in networks:
                comment = ""
                description = ""
                if network.description is not None:
                    description = network.description
                if network.comment is not None:
                    comment = network.comment
                rows.append([network.id, network.name, comment, description])
            output = Output(["ID", "Name", "Comment", "Description"], rows)
            output.print_table()
            self.c.close()
        except sdk.Error as err:
            print "Failed to list networks, %s" % str(err)

    def net_add(self, args):
        vms_service = self.c.system_service().vms_service()
        vm = vms_service.list(search=args.vm_name)[0]
        nics_service = vms_service.vm_service(vm.id).nics_service()
        index = len(nics_service.list())
        # nics_service.add method takes vnic profile id as the variable,
        # not the network id. So we have to find out the vnic profile id
        # by using network id
        # https://lab-rhevm.gsslab.pek2.redhat.com/ovirt-engine/api/vnicprofiles/00e3cad9-5383-494c-9524-f353b5e2c8be
        profiles_service = self.c.system_service().vnic_profiles_service()
        profile_id = None
        for profile in profiles_service.list():
            if profile.network.id == args.net_id:
                profile_id = profile.id
                break
        nic_name = 'nic'+str(index)
        try:
            nics_service.add(
                types.Nic(
                    name=nic_name,
                    description='My network interface card',
                    vnic_profile=types.VnicProfile(
                        id=profile_id,
                    ),
                ),
            )
            self.c.close()
        except sdk.Error as err:
            print "Failed to add NICs to %s, %s" % (args.vm_name, str(err))

    def net_rm(self, args):
        vms_service = self.c.system_service().vms_service()
        vm = vms_service.list(search=args.vm_name)[0]
        nic_service = vms_service.vm_service(vm.id).nics_service().nic_service(args.port_id)

        #nics_service = vms_service.vm_service(vm.id).nics_service()
        #VmNicService got remove function
        # http://ovirt.github.io/ovirt-engine-sdk/master/services.m.html#ovirtsdk4.services.HostService.nics_service
        # nics_service.add method takes vnic profile id as the variable,
        # not the network id. So we have to find out the vnic profile id
        # by using network id
        # https://lab-rhevm.gsslab.pek2.redhat.com/ovirt-engine/api/vnicprofiles/00e3cad9-5383-494c-9524-f353b5e2c8be

        try:
            nic_service.remove(
                types.Nic(
                    name=nic_name,
                    description='My network interface card',
                    vnic_profile=types.VnicProfile(
                        id=profile_id,
                    ),
                ),
            )
            self.c.close()
        except sdk.Error as err:
            print "Failed to add NICs to %s, %s" % (args.vm_name, str(err))
